import { CoinspotApiBase } from './coinspotApiBase';
import { FullAccessApiStatusResponse, CoinDepositAddressResponse, CancelOrderResponse, CoinWithdrawalDetailsResponse, BuySellQuoteResponse, SwapQuoteResponse, PlaceMarketBuySellOrderResponse, EditOpenMarketBuySellOrderResponse, PlaceBuySellNowOrderResponse, PlaceSwapNowOrderResponse, WithdrawCoinResponse } from './types';
export declare class CoinspotApi extends CoinspotApiBase {
    /**
     * Check the status of the API
     * @returns {Promise<FullAccessApiStatusResponse>} Object containing API status
     */
    checkFullAccessApiStatus(): Promise<FullAccessApiStatusResponse>;
    /**
     * Get deposit address for a specific coin
     * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
     * @returns {Promise<CoinDepositAddressResponse>} Object containing deposit address information for the specified coin
     */
    getCoinDepositAddress(cointype: string): Promise<CoinDepositAddressResponse>;
    /**
    * Get quote for buying a specific coin
    * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
    * @param {number} amount - Amount to buy
    * @param {string} amounttype - 'coin' or 'aud'
    * @returns {Promise<BuySellQuoteResponse>} Object containing buy quote for the specified coin
    */
    getBuyNowQuote(cointype: string, amount: number, amounttype: string): Promise<BuySellQuoteResponse>;
    /**
    * Get quote for selling a specific coin
    * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
    * @param {number} amount - Amount of coins to sell
    * @param {string} amounttype - 'coin' or 'aud'
    * @returns {Promise<BuySellQuoteResponse>} Object containing sell quote for the specified coin
    */
    getSellNowQuote(cointype: string, amount: number, amounttype: string): Promise<BuySellQuoteResponse>;
    /**
    * Get quote for swapping coins
    * @param {string} cointypesell - Coin short name to sell (e.g., 'BTC', 'LTC', 'DOGE')
    * @param {string} cointypebuy - Coin short name to buy (e.g., 'BTC', 'LTC', 'DOGE')
    * @param {number} amount - Amount of coins to swap
    * @returns {Promise<SwapQuoteResponse>} Object containing swap quote for the specified coins
    */
    getSwapNowQuote(cointypesell: string, cointypebuy: string, amount: number): Promise<SwapQuoteResponse>;
    /**
    * Place a market buy order
    * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
    * @param {number} amount - Amount of coins to buy
    * @param {number} rate - Rate in market currency
    * @param {string} [markettype='AUD'] - Market coin short name (e.g., 'USDT')
    * @returns {Promise<PlaceMarketBuySellOrderResponse>} Object containing details of the placed buy order
    */
    placeMarketBuyOrder(cointype: string, amount: number, rate: number, markettype?: string): Promise<PlaceMarketBuySellOrderResponse>;
    /**
    * Edit an open market buy order
    * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
    * @param {string} id - Order ID of the target buy order
    * @param {number} rate - Current rate of the open order
    * @param {number} newrate - Proposed new rate for the order
    * @returns {Promise<EditOpenMarketBuySellOrderResponse>} Object containing details of the edited buy order
    */
    editOpenMarketBuyOrder(cointype: string, id: string, rate: number, newrate: number): Promise<EditOpenMarketBuySellOrderResponse>;
    /**
    * Place a buy now order
    * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
    * @param {string} amounttype - 'coin' or 'aud'
    * @param {number} amount - Amount to buy
    * @param {number} [rate] - Rate in AUD (optional)
    * @param {number} [threshold] - Percentage threshold for rate variation (0 to 1000) (optional)
    * @param {string} [direction='UP'] - Direction for threshold: 'UP', 'DOWN', or 'BOTH' (optional)
    * @returns {Promise<PlaceBuySellNowOrderResponse>} Object containing details of the placed buy now order
    */
    placeBuyNowOrder(cointype: string, amounttype: string, amount: number, rate?: number, threshold?: number, direction?: string): Promise<PlaceBuySellNowOrderResponse>;
    /**
    * Place a market sell order
    * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
    * @param {number} amount - Amount of coins to sell
    * @param {number} rate - Rate in AUD
    * @param {string} [markettype='AUD'] - Market coin short name (e.g., 'USDT')
    * @returns {Promise<PlaceMarketBuySellOrderResponse>} Object containing details of the placed sell order
    */
    placeMarketSellOrder(cointype: string, amount: number, rate: number, markettype?: string): Promise<PlaceMarketBuySellOrderResponse>;
    /**
    * Edit an open market sell order
    * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
    * @param {string} id - Order ID of the target sell order
    * @param {number} rate - Current rate of the open order
    * @param {number} newrate - Proposed new rate for the order
    * @returns {Promise<EditOpenMarketBuySellOrderResponse>} Object containing details of the edited sell order
    */
    editOpenMarketSellOrder(cointype: string, id: string, rate: number, newrate: number): Promise<EditOpenMarketBuySellOrderResponse>;
    /**
    * Place a sell now order
    * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
    * @param {string} amounttype - 'coin' or 'aud'
    * @param {number} amount - Amount of coins to sell
    * @param {number} [rate] - Rate in AUD (optional)
    * @param {number} [threshold] - Percentage threshold for rate variation (0 to 1000) (optional)
    * @param {string} [direction='DOWN'] - Direction for threshold: 'UP', 'DOWN', or 'BOTH' (optional)
    * @returns {Promise<PlaceBuySellNowOrderResponse>} Object containing details of the placed sell now order
    */
    placeSellNowOrder(cointype: string, amounttype: string, amount: number, rate?: number, threshold?: number, direction?: string): Promise<PlaceBuySellNowOrderResponse>;
    /**
    * Place a swap now order
    * @param {string} cointypesell - Coin short name to sell (e.g., 'BTC', 'LTC', 'DOGE')
    * @param {string} cointypebuy - Coin short name to buy (e.g., 'BTC', 'LTC', 'DOGE')
    * @param {number} amount - Amount of coins to swap
    * @param {number} [rate] - Rate received from Swap Now Quote (optional)
    * @param {number} [threshold] - Percentage threshold for rate variation (0 to 1000) (optional)
    * @param {string} [direction='BOTH'] - Direction for threshold: 'UP', 'DOWN', or 'BOTH' (optional)
    * @returns {Promise<PlaceSwapNowOrderResponse>} Object containing details of the placed swap now order
    */
    placeSwapNowOrder(cointypesell: string, cointypebuy: string, amount: number, rate?: number, threshold?: number, direction?: string): Promise<PlaceSwapNowOrderResponse>;
    /**
    * Cancel a buy order
    * @param {string} id - ID of the buy order to cancel
    * @returns {Promise<CancelOrderResponse>} Object containing the cancellation status
    */
    cancelBuyOrder(id: string): Promise<CancelOrderResponse>;
    /**
    * Cancel all buy orders
    * @param {string} [coin] - Coin short name to cancel orders for (optional)
    * @returns {Promise<CancelOrderResponse>} Object containing the cancellation status
    */
    cancelAllBuyOrders(coin?: string): Promise<CancelOrderResponse>;
    /**
    * Cancel a sell order
    * @param {string} id - ID of the sell order to cancel
    * @returns {Promise<CancelOrderResponse>} Object containing the cancellation status
    */
    cancelSellOrder(id: string): Promise<CancelOrderResponse>;
    /**
    * Cancel all sell orders
    * @param {string} [coin] - Coin short name to cancel orders for (optional)
    * @returns {Promise<CancelOrderResponse>} Object containing the cancellation status
    */
    cancelAllSellOrders(coin?: string): Promise<CancelOrderResponse>;
    /**
    * Get coin withdrawal details
    * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
    * @returns {Promise<CoinWithdrawalDetailsResponse>} Object containing withdrawal details for the specified coin
    */
    getCoinWithdrawalDetails(cointype: string): Promise<CoinWithdrawalDetailsResponse>;
    /**
    * Withdraw coin
    * @param {string} cointype - Coin short name (e.g., 'BTC', 'LTC', 'DOGE')
    * @param {number} amount - Amount of coins to withdraw
    * @param {string} address - Destination address for the withdrawal
    * @param {string} [emailconfirm='NO'] - Whether to send email confirmation ('YES' or 'NO')
    * @param {string} [network] - Network to use for sending (e.g., 'BNB', 'ETH')
    * @param {string} [paymentid] - Payment ID/memo for the withdrawal (where applicable)
    * @returns {Promise<WithdrawCoinResponse>} Object containing the withdrawal status
    */
    withdrawCoin(cointype: string, amount: number, address: string, emailconfirm?: string, network?: string, paymentid?: string): Promise<WithdrawCoinResponse>;
}
//# sourceMappingURL=coinspotApi.d.ts.map